# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/osm/teams/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/osm/teams/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Osm\\Teams\\": "packages/osm/teams/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Osm\Teams\Providers\TeamsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Teams'  => Osm\Teams\Facades\Teams::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Osm\\TeamsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Osm\Teams\Providers\TeamsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Osm\Teams\Providers\TeamsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Osm\Teams\Providers\TeamsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/teams/{modulename}

**User**

    http://path-to-route-folder/user/teams/{modulename}

**Public**

    http://path-to-route-folder/teams


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/teams/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/teams/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/teams/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/teams/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/teams/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/teams/{modulename}/{slug}
    METHOD: GET